summaryrefslogtreecommitdiffstats
path: root/src/desktop.h
diff options
context:
space:
mode:
authorMarkus Engel <markus.engel@tum.de>2013-11-07 20:44:00 +0000
committerMarkus Engel <markus.engel@tum.de>2013-11-07 20:44:00 +0000
commit55b451bf382e0c3d5ed8728e42fbb535acfa8a33 (patch)
tree094d9faca06cfffc89a872732db4ac3ef60508d9 /src/desktop.h
parentFix for Bug #1247985 (Incorrect implementation of plural forms). (diff)
downloadinkscape-55b451bf382e0c3d5ed8728e42fbb535acfa8a33.tar.gz
inkscape-55b451bf382e0c3d5ed8728e42fbb535acfa8a33.zip
First step of moving tools into appropriate namespaces.
(bzr r12782)
Diffstat (limited to 'src/desktop.h')
-rw-r--r--src/desktop.h22
1 files changed, 16 insertions, 6 deletions
diff --git a/src/desktop.h b/src/desktop.h
index 938c2153a..faaa7e3a5 100644
--- a/src/desktop.h
+++ b/src/desktop.h
@@ -41,7 +41,17 @@ class SPCSSAttr;
struct SPCanvas;
struct SPCanvasItem;
struct SPCanvasGroup;
-class SPEventContext;
+
+namespace Inkscape {
+namespace UI {
+namespace Tools {
+
+class ToolBase;
+
+}
+}
+}
+
class SPItem;
class SPNamedView;
class SPObject;
@@ -110,7 +120,7 @@ namespace Inkscape {
* data, like grid and guideline placement, snapping options and so on.
*
* Associated with each SPDesktop are the two most important editing
* related objects - SPSelection and SPEventContext.
*
* Sodipodi keeps track of the active desktop and invokes notification
* signals whenever it changes. UI elements can use these to update their
@@ -128,14 +138,14 @@ public:
Inkscape::LayerModel *layers;
/// current selection; will never generally be NULL
Inkscape::Selection *selection;
- SPEventContext *event_context;
+ Inkscape::UI::Tools::ToolBase *event_context;
Inkscape::LayerManager *layer_manager;
Inkscape::EventLog *event_log;
DocumentInterface *dbus_document_interface;
Inkscape::Display::TemporaryItemList *temporary_item_list;
Inkscape::Display::SnapIndicator *snapindicator;
- SPEventContext* getEventContext() const;
+ Inkscape::UI::Tools::ToolBase* getEventContext() const;
Inkscape::Selection* getSelection() const;
SPDocument* getDocument() const;
SPCanvas* getCanvas() const;
@@ -207,7 +217,7 @@ public:
return _document_replaced_signal.connect (slot);
}
- sigc::connection connectEventContextChanged (const sigc::slot<void,SPDesktop*,SPEventContext*> & slot)
+ sigc::connection connectEventContextChanged (const sigc::slot<void,SPDesktop*,Inkscape::UI::Tools::ToolBase*> & slot)
{
return _event_context_changed_signal.connect (slot);
}
@@ -425,7 +435,7 @@ private:
sigc::signal<void,SPDesktop*,SPDocument*> _document_replaced_signal;
sigc::signal<void> _activate_signal;
sigc::signal<void> _deactivate_signal;
- sigc::signal<void,SPDesktop*,SPEventContext*> _event_context_changed_signal;
+ sigc::signal<void,SPDesktop*,Inkscape::UI::Tools::ToolBase*> _event_context_changed_signal;
sigc::signal<void, gpointer> _tool_subselection_changed;
sigc::connection _activate_connection;
@@ -110,7 +120,7 @@ namespace Inkscape {
*
* Associated with each SPDesktop are the two most important editing
- * related objects - SPSelection and SPEventContext.
+ * related objects - SPSelection and ToolBase.
*
* Sodipodi keeps track of the active desktop and invokes notification